Passage class

Main Passage class corresponding to the updated PassageJS interface.

Annotations
  • @JS.new('Passage')

Constructors

Passage(String appId, [PassageConfig? config])
factory

Properties

app → PassageApp
no setter
currentUser → PassageCurrentUser
no setter
hashCode → int
The hash code for this object.
no setterinherited
no setter
oneTimePasscode → PassageOneTimePasscode
no setter
passkey → PassagePasskey
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → PassageSession
no setter
social → PassageSocial
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited