PassageApp class

Constructors

PassageApp()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createUser(String identifier, {Metadata? userMetadata}) → Future<PublicUserInfo>
Creates a new user with the provided identifier and optional metadata. This method should be used to register a new user.
info() → Future<PassageAppInfo>
Gets information about an app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
userExists(String identifier) → Future<PublicUserInfo>
Checks if the provided identifier exists for the application. This method can be used to determine whether to register or log in a user.

Operators

operator ==(Object other) → bool
The equality operator.
inherited