AuthResult class

Implemented types

Constructors

AuthResult.fromJson(dynamic json)
factory
AuthResult.fromMap(Map<String, dynamic> map)

Properties

authToken → String
final
hashCode → int
The hash code for this object.
no setterinherited
redirectUrl → String?
final
refreshToken → String?
final
refreshTokenExpiration → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited