Metadata class

Implemented types

Constructors

Metadata({required dynamic userMetadata})
Metadata.fromJson(dynamic jsonInput)
factory
Metadata.fromMap(Map<String, dynamic> map)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userMetadata → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited