CurrentUser class

Implemented types

Constructors

CurrentUser.fromJson(dynamic jsonString)
factory
CurrentUser.fromMap(Map<String, dynamic> map)

Properties

createdAt → String?
final
email → String?
final
emailVerified → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
lastLoginAt → String?
final
loginCount → int?
final
phone → String?
final
phoneVerified → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
updatedAt → String?
final
userMetadata → dynamic
final
webauthn → bool
final
webauthnDevices → List?
final
webauthnTypes → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited