Passkey class

Implemented types

Constructors

Passkey.fromJson(dynamic jsonString)
factory
Passkey.fromMap(Map<String, dynamic> map)

Properties

createdAt → String
final
credId → String
final
friendlyName → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
lastLoginAt → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → String?
final
usageCount → int?
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited