PassageMagiclink class

Constructors

PassageMagiclink()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activate(String magicLink) → Future<AuthResult>
Activates a magic link. This function handles both login and registration magic links.
login(String identifier, {String? language}) → Future<MagicLink>
Creates and sends a new magic link for logging in.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String identifier, {String? language}) → Future<MagicLink>
Creates and sends a new magic link for registration.
status(String id) → Future<AuthResult>
Looks up a magic link by ID and checks if it has been verified. This function is most commonly used to iteratively check if a user has clicked a magic link to login. Once the link has been verified, Passage will return authentication information via this function. This enables cross-device login.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited